@@ -4,14 +4,19 @@ from functools import partial
 
 from tqdm.autonotebook import tqdm
 
-from .runtime import DevModes
+from .runtime import Options
 
-progressbar = partial(tqdm, dynamic_ncols=True)
+
+def progressbar(iterable=None, desc=None, total=None, *, silent=False,
+                **kwargs):
+    if not silent:
+        return tqdm(iterable, desc, total, dynamic_ncols=True, **kwargs)
+    return iterable
 
 
 def get_logger(name, level=None, log_file=None):
     if level is None:
-        level = logging.INFO if not 'log' in DevModes else logging.DEBUG
+        level = logging.INFO if not Options.print_debug_log else logging.DEBUG
     logger = logging.getLogger(name)
     logger.setLevel(level)
     if len(logger.handlers) > 0:
